@@ -9,7 +9,7 @@ sys.path.insert(0, parentdir+"/net_emulator")
 from objects.emulator import SimpleEmulator
 from objects.cc_base import CongestionControl
 from player.block_selection import Solution as BlockSelection
-from net_utils.utils import *
+from utils import *
 from config.constant import *
 from config import constant
 
