@@ -1,5 +1,5 @@
 from config.constant import *
-from net_utils.utils import debug_print
+from utils import debug_print
 from objects.cc_base import CongestionControl
 
 
